local G13BarManager, ns = ...

--Build the empty Options panel
OptionsPanel = CreateFrame("Frame", "G13OptionsPanel", UIParent)
OptionsPanel.name = "G13 Bar Manager"


local function HideHotKeys()
	for i = 1, 12 do
		_G["MultiBarBottomLeftButton"..i.."HotKey"]:SetAlpha(0)
		_G["ActionButton"..i.."HotKey"]:SetAlpha(0)
	end
end

local function ShowHotKeys()
	for i = 1, 12 do
		_G["MultiBarBottomLeftButton"..i.."HotKey"]:SetAlpha(1)
		_G["ActionButton"..i.."HotKey"]:SetAlpha(1)
	end
end

--This code is for the black boxes when the bars are unlocked and movable.
local function SetBackground(frame)
	frame:SetBackdrop({
	 bgFile="Interface\\ChatFrame\\ChatFrameBackground",
	 edgeFile="Interface\\ChatFrame\\ChatFrameBackground",
	 tile=true,
	 tileSize=5,
	 edgeSize= 1,
	})
	frame:SetBackdropColor(0,0,0,1)
	frame:SetBackdropBorderColor(0,0,0,1)
end

local function ClearBackground(frame)
	frame:SetBackdrop(nil)
end

--Sets a given frame to be movable
local function MakeDraggable(frame)
	frame:SetMovable(true)
	frame:EnableMouse(true)
	frame:RegisterForDrag("LeftButton")
	frame:SetScript("OnDragStart", frame.StartMoving)
	frame:SetScript("OnDragStop", frame.StopMovingOrSizing)
end

--Sets a frame to be immovable
local function MakeStatic(frame)
	frame:SetMovable(false)
	frame:EnableMouse(false)
end

local function UnlockFrame(frame)
	MakeDraggable(frame)
	SetBackground(frame)
end

local function LockFrame(frame)
	MakeStatic(frame)
	ClearBackground(frame)
end

--Hides all the buttons when we unlock the bars.
local function HideAllButtons()
	for _, v in pairs(MenuButtons) do
		v:Hide()
	end
	for i = 1, 12 do
		_G["ActionButton"..i]:Hide()
		_G["MultiBarBottomLeftButton"..i]:Hide()
		_G["MultiBarBottomRightButton"..i]:Hide()
	end
	for i = 1, 10 do
		_G["PetActionButton"..i]:Hide()
	end
	for i = 1, 6 do
		_G["StanceButton"..i]:Hide()
	end
	for i = 0, 3 do
		_G["CharacterBag"..i.."Slot"]:Hide()
	end
	MainMenuBarBackpackButton:Hide()
end

--Shows the buttons again when the bars are locked.
local function ShowAllButtons()
	for _, v in pairs(MenuButtons) do
		v:Show()
	end
	for i = 1, 12 do
		_G["ActionButton"..i]:Show()
		_G["MultiBarBottomLeftButton"..i]:Show()
		_G["MultiBarBottomRightButton"..i]:Show()
	end
	for i = 1, 10 do
		_G["PetActionButton"..i]:Show()
	end
	for i = 1, 6 do
		_G["StanceButton"..i]:Show()
	end
	for i = 0, 3 do
		_G["CharacterBag"..i.."Slot"]:Show()
	end
	MainMenuBarBackpackButton:Show()
end

local function SaveBarPosition(bar)
	point, relativeTo, relativePoint, xOffset, yOffset = bar:GetPoint()
	s = bar:GetName()
	cfg = ns.cfg[s]
	cfg.point = point
	cfg.xOfs = xOffset
	cfg.yOfs = yOffset
end

--Here we check the SavedVariables after the addon is loaded.
--These were obtained earlier in the core addon code file.
OptionsPanel:RegisterEvent("ADDON_LOADED")
OptionsPanel:SetScript("OnEvent", function(self)
	if ns.cfg.HKVis == false then
		HideHotKeys()
	end
	--if G13BarManager.MenuVis == false then
	--	G13MenuBar:Hide()
	--end
end)

InterfaceOptions_AddCategory(OptionsPanel)

--Set up the slash command
SLASH_G13BARMANAGER1 = '/g13'

function SlashCmdList.G13BARMANAGER(msg, editbox)
	--We have to call this twice because Blizzard UI behaves oddly.
	--You may think you can remove one.
	--You can't.  Really, please don't.
	--Doing so will make it fail on some systems.
	InterfaceOptionsFrame_OpenToCategory("G13 Bar Manager")
	InterfaceOptionsFrame_OpenToCategory("G13 Bar Manager")
end

--This is the button for toggling the MenuBar visibility.
--It is temporarilly disabled so I can troubleshoot
--the visibility functions not working correctly.
--[[
local MenuBarButton = CreateFrame("Button","G13MenuBarButton", OptionsPanel, 'OptionsButtonTemplate') 
MenuBarButton:SetSize(150, 30)
MenuBarButton:SetPoint("TOPLEFT", OptionsPanel, 10, -10)
MenuBarButton:RegisterForClicks("AnyUp")
MenuBarButton:SetText("Toggle Menu Bar")
MenuBarButton:SetScript("OnClick", function(self, button)
	if G13BarManager.MenuVis == true then
		G13MenuBar:Hide()
		G13BarManager.MenuVis = false
	else
		G13MenuBar:Show()
		G13BarManager.MenuVis = true
	end
end)
--]]


--This is the button for toggling the HotKeys visibility.
local HotKeyButton = CreateFrame("Button","G13HotkeyButton", OptionsPanel, 'OptionsButtonTemplate') 
HotKeyButton:SetSize(150, 30)
--HotKeyButton:SetPoint("TOPLEFT", MenuBarButton, "BOTTOMLEFT",  0, -10)
HotKeyButton:SetPoint("TOPLEFT", OptionsPanel, 10, -10)
HotKeyButton:RegisterForClicks("AnyUp")
HotKeyButton:SetText("Toggle Hotkey Text")
HotKeyButton:SetScript("OnClick", function(self, button)
	if ActionButton1HotKey:GetAlpha() == 1 then
		HideHotKeys()
		ns.cfg.HKVis = false
	else
		ShowHotKeys()
		ns.cfg.HKVis = true
	end
end)

--This is a list of all the bars we have created. It could possibly be moved to the AllBars
--file, but for now it works here.  I'll revisit this during a code refactor, possibly.

local G13BarsList = {
	G13MainBar,
	G13BRBar,
	G13PetBar,
	G13StanceBar,
	G13BagBar,
	G13MenuBar
}

--This is a checkbutton to toggle the movability of the bars.
local BarLockCheckbutton = CreateFrame("CheckButton", "G13BarLockCheckbutton", OptionsPanel, 'OptionsCheckButtonTemplate')
BarLockCheckbutton:SetPoint("TOPLEFT", HotKeyButton, "BOTTOMLEFT",  0, -10)
_G[BarLockCheckbutton:GetName() .. "Text"]:SetText("Unlock Action Bars")
BarLockCheckbutton:SetScript("OnClick", function(self, checkbutton)
	if self:GetChecked() then
		HideAllButtons()
		for _, v in pairs(G13BarsList) do
			UnlockFrame(v)
		end
	else
		ShowAllButtons()
		for _, v in pairs(G13BarsList) do
			LockFrame(v)
			SaveBarPosition(v)
		end
	end
end)